@@ -43,10 +43,10 @@
 
 struct _xlator;
 typedef struct _xlator xlator_t;
-struct _dir_entry_t;
-typedef struct _dir_entry_t dir_entry_t;
-struct _gf_dirent_t;
-typedef struct _gf_dirent_t gf_dirent_t;
+struct _dir_entry;
+typedef struct _dir_entry dir_entry_t;
+struct _gf_dirent;
+typedef struct _gf_dirent gf_dirent_t;
 struct _loc;
 typedef struct _loc loc_t;
 
@@ -1043,8 +1043,11 @@ enum gf_hdsk_event_notify_op {
 gf_boolean_t
 is_graph_topology_equal (glusterfs_graph_t *graph1, glusterfs_graph_t *graph2);
 int
-glusterfs_volfile_reconfigure (int oldvollen, FILE *newvolfile_fp,
-                               glusterfs_ctx_t *ctx, const char *oldvolfile);
+glusterfs_volfile_reconfigure (FILE *newvolfile_fp, glusterfs_ctx_t *ctx);
+
+int
+gf_volfile_reconfigure (int oldvollen, FILE *newvolfile_fp,
+                        glusterfs_ctx_t *ctx, const char *oldvolfile);
 
 int
 loc_touchup (loc_t *loc, const char *name);
@@ -1063,4 +1066,8 @@ void xlator_init_unlock (void);
 int
 copy_opts_to_child (xlator_t *src, xlator_t *dst, char *glob);
 
+int
+glusterfs_delete_volfile_checksum (glusterfs_ctx_t *ctx,
+                                   const char *volfile_id);
+
 #endif /* _XLATOR_H */
